
# NoisyDARTS: Noisy Differentiable Architecture Search

This repository includes the implementation of our submitted NoisyDARTS paper. 

## Requirements

To install requirements:

```setup
pip install -r requirements.txt
```

We use CIFAR-10 and ImageNet datasets, which can be downloaded by `torchvision` automatically. We follow the standard preprocessing for both datasets.

## Searching

To perform a standard NoisyDARTS search, execute for example:

```searching
nohup python -u train_search.py --exp_name noisy_darts_a --factor_skip 0.2 --add_noise_skip --gpu 0 --seed 10 > noisy_darts_a.log 2>&1 &

```

## Training

To train the model(s) in the paper, run for example:

```train
nohup python -u train.py --auxiliary --cutout --save noisy_darts_a --arch noisy_darts_a --gpu 0 > noisy_darts_a.log 2>&1 &
```


## Evaluation

To evaluate CIFAR models, run for example:

```eval
python verify.py --auxiliary --arch noisy_darts_a --model-path pretrained/noisy_darts_a.pt
```

More evalutaion commands can be found in `scripts/run_verify.sh`.

## Pre-trained Models

You can download pretrained models here:

- All [NoisyDARTS models](https://drive.google.com/drive/folders/1sf5D-7Le0_MLE5w39rZ5ErY2Wd42dEs8?usp=sharing) can be downloaded from this anonymized link.

## Results

### NoisyDARTS Models Searched on CIFAR-10

| Models         | Search Strategy | Multiply-adds (M)| Parameters (M) | Top-1 (%) | 
| -------------- | ----------------| ----------- | ----------- | ---- |
| NoisyDARTS-a   | Gaussian, std=0.2 |   534   | 3.25 | **97.61** |
| NoisyDARTS-b   | Gaussian, std=0.1 |   511   | 3.09 | 97.53 |
| NoisyDARTS-c   | Uniform, std=0.2  |   539   | 3.33 | 97.40 |
| NoisyDARTS-d   | Uniform, std=0.1  |   501   | 3.06 | 97.42 |
| NoisyDARTS-e   | Gaussian, Multiplicative, std=0.2 |   539   | 3.24 | 97.55 |
| NoisyDARTS-f   | Gaussian, Multiplicative, std=0.1 |   443   | 2.68 | 97.18 |
| NoisyDARTS-g   | Gaussian, std=0.2, mean=0.5  | 549     | 3.32 | 97.49 |
| NoisyDARTS-h   | Gaussian, std=0.2, mean=1.0 | 511     | 3.01 | 97.35 |
| NoisyDARTS-i   | Gaussian, std=0.1, mean=0.5 | 495     | 3.07 | 97.28 |
| NoisyDARTS-j   | Gaussian, std=0.1, mean=1.0 | 476     | 2.94 | 97.21 |


Our average result compared with the prior art,

| Benchmark | DARTS      | RobustDARTS |  SDARTS    | NoisyDARTS  |
| ----------| ---------- | ----------- | --------   | ----------- |
| CIFAR-10  | 97.09±0.25 | 97.05±0.21  | 97.33±0.03 | 97.30±0.23  |

### Image Classification on ImageNet

| Model name         | Top 1 Accuracy  | Top 5 Accuracy |
| ------------------ |---------------- | -------------- |
| NoisyDARTS-A       |     77.9%       |      94.0%     |


## Other Experiment Details


* We use standard hyper-parameters for searching and training, except the minimum hyperparameters for noise specification.
* For searching in DARTS, we run each group of searching 8 times to get the average. 
* For searching in reduced Search space S2 and S3 of RDARTS, we run each setting for three times as done in RDARTS.
* Every single model is trained only once.
* Searching takes 0.4 GPU days.
* Single model training takes about 1.6 GPU days on average.
* We use a standard NVidia V100 for all the experiments.

