import argparse
import math

class CosineDecayScheduler(object):
    def __init__(self, base_lr=1.0, last_iter=0, T_max=50):
        self.base_lr = base_lr
        self.last_iter = last_iter
        self.T_max = T_max
        self.cnt = 0
        self.decay_rate = self.base_lr 

    def decay_rate(self, step):
        self.last_iter = step
        self.decay_rate = self.base_lr * (1 + math.cos(math.pi * self.last_iter / self.T_max)) / 2.0 if self.last_iter <= self.T_max else 0
        return self.decay_rate

parser = argparse.ArgumentParser("modelnet")
parser.add_argument('--data', type=str, default='../../data', help='location of the data corpus')
parser.add_argument('--batch_size', type=int, default=28, help='batch size')
parser.add_argument('--batch_increase', default=4, type=int,
                    help='how much does the batch size increase after making a decision')
parser.add_argument('--learning_rate', type=float, default=0.005, help='init learning rate')
parser.add_argument('--learning_rate_min', type=float, default=0.0001, help='min learning rate')
parser.add_argument('--momentum', type=float, default=0.9, help='momentum')
parser.add_argument('--weight_decay', type=float, default=3e-4, help='weight decay')
parser.add_argument('--report_freq', type=float, default=50, help='report frequency')
parser.add_argument('--gpu', type=int, default=0, help='gpu device id')
parser.add_argument('--init_channels', type=int, default=32, help='num of init channels')
parser.add_argument('--num_cells', type=int, default=2, help='total number of cells')
parser.add_argument('--n_steps', type=int, default=3, help='total number of layers in one cell')
parser.add_argument('--model_path', type=str, default='saved_models', help='path to save the model')
parser.add_argument('--cutout', action='store_true', default=False, help='use cutout')
parser.add_argument('--cutout_length', type=int, default=16, help='cutout length')
parser.add_argument('--drop_path_prob', type=float, default=0.3, help='drop path probability')
parser.add_argument('--save', type=str, default='ModelNet10', help='experiment name')
parser.add_argument('--seed', type=int, default=2, help='random seed')
parser.add_argument('--random_seed', action='store_true', help='use seed randomly')
parser.add_argument('--grad_clip', type=float, default=5, help='gradient clipping')
parser.add_argument('--train_portion', type=float, default=0.5, help='portion of training data')
parser.add_argument('--unrolled', action='store_true', default=False, help='use one-step unrolled validation loss')
parser.add_argument('--arch_learning_rate', type=float, default=3e-4, help='learning rate for arch encoding')
parser.add_argument('--arch_weight_decay', type=float, default=1e-3, help='weight decay for arch encoding')
parser.add_argument('--warmup_dec_epoch', type=int, default=9, help='warmup decision epoch')
parser.add_argument('--decision_freq', type=int, default=7, help='decision freq epoch')
parser.add_argument('--history_size', type=int, default=4, help='number of stored epoch scores')
parser.add_argument('--use_history', action='store_true', help='use history for decision')
parser.add_argument('--in_channels', default=3, type=int, help='the channel size of input point cloud ')
parser.add_argument('--emb_dims', default=1024, type=int, help='the channel size of embedding features ')
parser.add_argument('--dropout', default=0.5, type=float, help='dropout ratio')
parser.add_argument('--k', default=9, type=int, help='the kernel size of graph convolutions')
parser.add_argument('--num_points', default=1024, type=int, help='the number of points sampled from modelNet')
parser.add_argument('--post_val', action='store_true', default=False, help='validate after each decision')
# Adapted for NoisyDARTS
parser.add_argument('--disable_sgas', action='store_true', default=False, help='turn off sgas edge selection')
parser.add_argument('--noise_mean', type=float, default=0.0, help='noise mean, shared by skip and pooling')
parser.add_argument('--noise_type', type=str, default='gaussian', choices=['gaussian', 'uniform'], help='noise type')
parser.add_argument('--noise_mixture', type=str, default='additive', choices=['additive', 'multiplicative'], help='noise mixture type')
parser.add_argument('--noise_decay', action='store_true', default=False, help='add noise decay or not')
parser.add_argument('--add_noise_skip', action='store_true', default=False, help='add noise to skip')
parser.add_argument('--factor_skip', type=float, default=0.2, help='noise factor of std to skip')

args = parser.parse_args()
noise_decay_schedular = CosineDecayScheduler()
